@@ -556,12 +556,7 @@ def _get_all_tools() -> dict[str, Any]:
             create_subagent,
             s3_memory,
             listen,
-            realistic_speak,
-            speak_bark,
             sqlite_memory,
-            data_viz_tool,
-            graph_db_tool,
-            sql_tool,
             store_in_kb,
             system_prompt,
             bitchat,
@@ -582,7 +577,6 @@ def _get_all_tools() -> dict[str, Any]:
             image_reader,
             journal,
             diagram,
-            use_computer,
             mcp_client,
             load_tool,
             memory,
@@ -602,12 +596,7 @@ def _get_all_tools() -> dict[str, Any]:
         tools = {
             "listen": listen,
             "bitchat": bitchat,
-            "data_viz_tool": data_viz_tool,
-            "graph_db_tool": graph_db_tool,
-            "sql_tool": sql_tool,
             "store_in_kb": store_in_kb,
-            "realistic_speak": realistic_speak,
-            "speak_bark": speak_bark,
             "graphql": graphql,
             "use_github": use_github,
             "fetch_github_tool": fetch_github_tool,
@@ -634,7 +623,6 @@ def _get_all_tools() -> dict[str, Any]:
             "image_reader": image_reader,
             "journal": journal,
             "diagram": diagram,
-            "use_computer": use_computer,
             "load_tool": load_tool,
             "system_prompt": system_prompt,
             "s3_memory": s3_memory,
@@ -894,7 +882,6 @@ def main():
 - **use_agent** - Use different AI models for specific tasks
 - **tasks** - Run background tasks and processes
 - **listen** - Background speech transcription with trigger keywords
-- **realistic_speak** - Generate realistic speech with DIA model (emotions, nonverbals, voice cloning)
 - **bitchat** - P2P encrypted mesh communication over Bluetooth for agent-to-agent networking
 - **dialog** - Interactive forms and user input (optional)
 - **event_bridge** - Team collaboration and distributed context (optional)
@@ -1204,6 +1191,7 @@ agent.tool.graph_db_tool(...)
                 auto_suggest=AutoSuggestFromHistory(),
                 completer=completer,
                 complete_while_typing=True,
+                mouse_support=False,  # breaks scrolling when enabled
             )
 
             if q.startswith("!"):
